class ConferenceImportJob < ApplicationJob
  queue_as :default

  def perform(conference_slug)
    conference = Conference.find_by(slug: conference_slug)
    return unless conference

    if conference.import_in_progress? && conference.last_import_started_at > 5.minutes.ago
      Rails.logger.info "Skipping import for #{conference_slug} as another import is already in progress"
      return
    end

    if conference.import_completed? && conference.last_import_completed_at > 5.minutes.ago
      Rails.logger.info "Skipping import for #{conference_slug} as it was recently imported"
      return
    end

    if conference.retry_count >= 3 && conference.last_import_started_at > 1.hour.ago
      Rails.logger.info "Skipping import for #{conference_slug} due to too many recent failures"
      return
    end

    FetchConferenceDataJob.perform_later(conference_slug)
  end
end
